#   htmlcc - Statically compiled HTML templates for C
#   Copyright (C) 2025  Lee Yingtong Li
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.

from .emitter import Emitter, known_emitters
from .emitter.cgit import CgitEmitter
from .parser import Parser

import argparse

# Initialise ArgumentParser
arg_parser = argparse.ArgumentParser(prog='htmlcc', description='Statically compiled HTML templates for C')
arg_parser.add_argument('--emitter', default='cgit', choices=list(known_emitters.keys()))
arg_parser.add_argument('filename', nargs='+')

args = arg_parser.parse_args()

emitter = known_emitters[args.emitter]()
emitter.emit_preamble()

# Process files
for filename in args.filename:
	with open(filename, 'r') as f:
		content = f.read()  # Entire file must be read into memory for str.index etc.
		parser = Parser(buffer=content, emitter=emitter)
		parser.parse()
